@@ -2,11 +2,13 @@ import os
 from ConfigParser import ConfigParser
 from config import Config
 from owncloud import setup
-from insider.facade import get_deployed_insider
 from trusted import Trusted
 from access import Access
 from https import Https
 
+default_config_path = '/usr/local/config'
+
+
 class OwncloudControl:
     def __init__(self, config, insider, access):
         self.insider = insider
@@ -29,7 +31,7 @@ class OwncloudControl:
         return urls.full_url
 
 
-def get_control(config_path, insider):
+def get_control(insider, config_path=default_config_path):
     config_filename = os.path.join(config_path, 'owncloud-ctl.cfg')
 
     parser = ConfigParser()
@@ -48,9 +50,4 @@ def get_control(config_path, insider):
     https = Https(config)
     access = Access(config, insider, trusted, https)
 
-    return OwncloudControl(config, insider, access)
-
-def get_deployed_control():
-    insider = get_deployed_insider()
-    control = get_control('/usr/local/config', insider)
-    return control
+    return OwncloudControl(config, insider, access)
\ No newline at end of file
